# nn-wtf - Neural Networks Wrapper for TensorFlow

nn-wtf aims at providing a convenience wrapper to Google's 
[TensorFlow](http://www.tensorflow.org/) machine learning library. 
Its focus is on making neural networks easy to set up, train and use.
